# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from ...Datatypes.KlAudioversterkerMerk import KlAudioversterkerMerk
from ...Datatypes.KlAudioversterkerModelnaam import KlAudioversterkerModelnaam
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Audioversterker(AIMNaamObject, PuntGeometrie):
    """Elk toestel dat een inkomend audiosignaal omzet naar een signaal dat meerdere luidsprekers kan aansturen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Meetmicrofoon', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack', direction='i')  # i = direction: incoming

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='IP-adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker.ipAdres',
                                     kardinaliteit_max='2',
                                     definition='Het IP-adres van de audioversterker.',
                                     owner=self)

        self._merk = OTLAttribuut(field=KlAudioversterkerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker.merk',
                                  definition='Het merk van de audioversterker.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlAudioversterkerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker.modelnaam',
                                       definition='De modelnaam van de audioversterker.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker.technischeFiche',
                                             definition='De technische fiche van de audioversterker.',
                                             owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> List[DteIPv4AdresWaarden]:
        """Het IP-adres van de audioversterker."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de audioversterker."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de audioversterker."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de audioversterker."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlKwaliteitsklasseHout(KeuzelijstField):
    """De kwaliteitsindeling van hout met betrekking op vervormingen, scheuren en kwasten."""
    naam = 'KlKwaliteitsklasseHout'
    label = 'Kwaliteitsklasse van hout'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlKwaliteitsklasseHout'
    definition = 'De kwaliteitsindeling van hout met betrekking op vervormingen, scheuren en kwasten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlKwaliteitsklasseHout'
    options = {
        'klasse-a': KeuzelijstWaarde(invulwaarde='klasse-a',
                                     label='Klasse A',
                                     status='ingebruik',
                                     definitie='De hoogste kwaliteitsklasse die uitsluitend bedoeld is voor toepassingen waarbij zeer hoge eisen aan het uiterlijk worden gesteld. Dit hout gevat geen holtes of oneffenheden en is tevens onbehandeld.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKwaliteitsklasseHout/klasse-a'),
        'klasse-b': KeuzelijstWaarde(invulwaarde='klasse-b',
                                     label='Klasse B',
                                     status='ingebruik',
                                     definitie='Hout dat zowel sterk is als er goed uitziet met weinig knoesten en geen hart. Het is afkomstig uit Noord- Europa en wordt ook bestempeld als constructiehout. Klasse B-hout is van lagere kwaliteit dan A-hout en kan niet worden hergebruikt. Als er een afwerklaag wordt aangebracht en onderhouden, heeft het hout een kwaliteitsklasse B.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKwaliteitsklasseHout/klasse-b'),
        'klasse-c': KeuzelijstWaarde(invulwaarde='klasse-c',
                                     label='Klasse C',
                                     status='ingebruik',
                                     definitie='Klasse C-hout geldt als standaard en is voornamelijk afkomstig uit Noord-Europa, waar de bomen in duurzame bossen geteeld worden. Gezonde knoesten zijn toegestaan, evenals een beetje hart. Dit hout is van lagere kwaliteit dan A-hout en kan niet worden hergebruikt. Klasse C houdt ook in dat het hout geïmpregneerd is. ',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKwaliteitsklasseHout/klasse-c'),
        'tropisch-hardhout': KeuzelijstWaarde(invulwaarde='tropisch-hardhout',
                                              label='Tropisch hardhout',
                                              status='ingebruik',
                                              definitie='Zwaardere houtsoorten uit de tropen, zoals vb.: azobé (afkomstig uit tropische bossen in Afrika). ',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKwaliteitsklasseHout/tropisch-hardhout')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.HoutenConstructieElement import HoutenConstructieElement
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.IntegerField import IntegerField
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class HoutenBeplanking(HoutenConstructieElement, AIMNaamObject, LijnGeometrie, VlakGeometrie):
    """De beplanking in hout van een waterbouwkundige constructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenBeplanking'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BeweegbareWaterkerendeConstructie', direction='o')  # o = direction: outgoing

        self._aantalLagen = OTLAttribuut(field=IntegerField,
                                         naam='aantalLagen',
                                         label='aantal lagen',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenBeplanking.aantalLagen',
                                         definition='Het aantal lagen dat de beplanking bevat.',
                                         owner=self)

        self._totaleDikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                         naam='totaleDikte',
                                         label='totale dikte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenBeplanking.totaleDikte',
                                         definition='De totale dikte (van alle lagen samen) van de houtenbeplanking, uitgedrukt in millimeter.',
                                         owner=self)

    @property
    def aantalLagen(self) -> int:
        """Het aantal lagen dat de beplanking bevat."""
        return self._aantalLagen.get_waarde()

    @aantalLagen.setter
    def aantalLagen(self, value):
        self._aantalLagen.set_waarde(value, owner=self)

    @property
    def totaleDikte(self) -> KwantWrdInMillimeterWaarden:
        """De totale dikte (van alle lagen samen) van de houtenbeplanking, uitgedrukt in millimeter."""
        return self._totaleDikte.get_waarde()

    @totaleDikte.setter
    def totaleDikte(self, value):
        self._totaleDikte.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAardingsInstallatieType(KeuzelijstField):
    """Een keuzelijst waarin aangeduid kan worden over welke aardingsinstallatietype het gaat."""
    naam = 'KlAardingsInstallatieType'
    label = 'Type van aardingsinstallatie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlAardingsInstallatieType'
    definition = 'Een keuzelijst waarin aangeduid kan worden over welke aardingsinstallatietype het gaat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAardingsInstallatieType'
    options = {
        'hoogspanningsinstallatie': KeuzelijstWaarde(invulwaarde='hoogspanningsinstallatie',
                                                     label='hoogspanningsinstallatie',
                                                     status='ingebruik',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAardingsInstallatieType/hoogspanningsinstallatie'),
        'laagspanningsinstallatie': KeuzelijstWaarde(invulwaarde='laagspanningsinstallatie',
                                                     label='laagspanningsinstallatie',
                                                     status='ingebruik',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAardingsInstallatieType/laagspanningsinstallatie'),
        'nulpuntinstallatie': KeuzelijstWaarde(invulwaarde='nulpuntinstallatie',
                                               label='nulpuntinstallatie',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAardingsInstallatieType/nulpuntinstallatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWijzeGeleiding(KeuzelijstField):
    """De mogelijke wijzen van geleiding."""
    naam = 'KlWijzeGeleiding'
    label = 'Wijze geleiding'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlWijzeGeleiding'
    definition = 'De mogelijke wijzen van geleiding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWijzeGeleiding'
    options = {
        'continu': KeuzelijstWaarde(invulwaarde='continu',
                                    label='continu',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWijzeGeleiding/continu'),
        'discreet': KeuzelijstWaarde(invulwaarde='discreet',
                                     label='discreet',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWijzeGeleiding/discreet')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeConcept(KeuzelijstField):
    """De mogelijke types van concepten van een beweegbare waterkerende constructie."""
    naam = 'KlTypeConcept'
    label = 'type beweging'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlTypeConcept'
    definition = 'De mogelijke types van concepten van een beweegbare waterkerende constructie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeConcept'
    options = {
        'cilinder': KeuzelijstWaarde(invulwaarde='cilinder',
                                     label='cilinder',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/cilinder'),
        'draai': KeuzelijstWaarde(invulwaarde='draai',
                                  label='draai',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/draai'),
        'glij': KeuzelijstWaarde(invulwaarde='glij',
                                 label='glij',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/glij'),
        'hef': KeuzelijstWaarde(invulwaarde='hef',
                                label='hef',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/hef'),
        'jaloezieofspiegel': KeuzelijstWaarde(invulwaarde='jaloezieofspiegel',
                                              label='jaloezieOfSpiegel',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/jaloezieofspiegel'),
        'klep': KeuzelijstWaarde(invulwaarde='klep',
                                 label='klep',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/klep'),
        'punt': KeuzelijstWaarde(invulwaarde='punt',
                                 label='punt',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/punt'),
        'rol': KeuzelijstWaarde(invulwaarde='rol',
                                label='rol',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/rol'),
        'sector': KeuzelijstWaarde(invulwaarde='sector',
                                   label='sector',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/sector'),
        'segment': KeuzelijstWaarde(invulwaarde='segment',
                                    label='segment',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/segment'),
        'vlinder': KeuzelijstWaarde(invulwaarde='vlinder',
                                    label='vlinder',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/vlinder'),
        'waaier': KeuzelijstWaarde(invulwaarde='waaier',
                                   label='waaier',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/waaier'),
        'wiel': KeuzelijstWaarde(invulwaarde='wiel',
                                 label='wiel',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/wiel'),
        'zink': KeuzelijstWaarde(invulwaarde='zink',
                                 label='zink',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeConcept/zink')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Stuwconstructie(AIMNaamObject, LijnGeometrie):
    """Een debietbegrenzende constructie waarbij het af te voeren water in zijn geheel door een (knijp)opening stroomt bij normale afvoer. Bij hevige regenval, wanneer de watertoevoer niet meer kan worden verwerkt, wordt een buffer opgebouwd tot aan de overstort."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuwconstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='o')  # o = direction: outgoing

        self._breedteUitsparing = OTLAttribuut(field=KwantWrdInMillimeter,
                                               naam='breedteUitsparing',
                                               label='breedte uitsparing',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuwconstructie.breedteUitsparing',
                                               definition='De breedte van het uitgesneden deel dat de functie heeft van overstort in millimeter.',
                                               owner=self)

        self._diameterKnijpopening = OTLAttribuut(field=KwantWrdInMillimeter,
                                                  naam='diameterKnijpopening',
                                                  label='diameter knijpopening',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuwconstructie.diameterKnijpopening',
                                                  definition='De diameter van de opening onderaan de cascade die zorgt voor een vertraagde waterafvoer bij hevige regenval of overvloedige toevoer van water in millimeter.',
                                                  owner=self)

        self._overstortpeil = OTLAttribuut(field=KwantWrdInMeterTAW,
                                           naam='overstortpeil',
                                           label='overstortpeil',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stuwconstructie.overstortpeil',
                                           definition='Drempelpeil van de overstort. Uitgedrukt in meter-TAW gemeten in het midden van de drempel.',
                                           owner=self)

    @property
    def breedteUitsparing(self) -> KwantWrdInMillimeterWaarden:
        """De breedte van het uitgesneden deel dat de functie heeft van overstort in millimeter."""
        return self._breedteUitsparing.get_waarde()

    @breedteUitsparing.setter
    def breedteUitsparing(self, value):
        self._breedteUitsparing.set_waarde(value, owner=self)

    @property
    def diameterKnijpopening(self) -> KwantWrdInMillimeterWaarden:
        """De diameter van de opening onderaan de cascade die zorgt voor een vertraagde waterafvoer bij hevige regenval of overvloedige toevoer van water in millimeter."""
        return self._diameterKnijpopening.get_waarde()

    @diameterKnijpopening.setter
    def diameterKnijpopening(self, value):
        self._diameterKnijpopening.set_waarde(value, owner=self)

    @property
    def overstortpeil(self) -> KwantWrdInMeterTAWWaarden:
        """Drempelpeil van de overstort. Uitgedrukt in meter-TAW gemeten in het midden van de drempel."""
        return self._overstortpeil.get_waarde()

    @overstortpeil.setter
    def overstortpeil(self, value):
        self._overstortpeil.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBVMengseltype(KeuzelijstField):
    """het mengseltype van de butimineuze verharding."""
    naam = 'KlBVMengseltype'
    label = 'BV mengseltype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBVMengseltype'
    definition = 'het mengseltype van de butimineuze verharding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBVMengseltype'
    options = {
        'AB-1B': KeuzelijstWaarde(invulwaarde='AB-1B',
                                  label='AB-1B',
                                  status='ingebruik',
                                  definitie='AB-1B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-1B'),
        'AB-2C': KeuzelijstWaarde(invulwaarde='AB-2C',
                                  label='AB-2C',
                                  status='ingebruik',
                                  definitie='AB-2C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-2C'),
        'AB-3A': KeuzelijstWaarde(invulwaarde='AB-3A',
                                  label='AB-3A',
                                  status='ingebruik',
                                  definitie='AB-3A',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3A'),
        'AB-3B': KeuzelijstWaarde(invulwaarde='AB-3B',
                                  label='AB-3B',
                                  status='ingebruik',
                                  definitie='AB-3B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3B'),
        'AB-3C': KeuzelijstWaarde(invulwaarde='AB-3C',
                                  label='AB-3C',
                                  status='ingebruik',
                                  definitie='AB-3C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3C'),
        'AB-3D': KeuzelijstWaarde(invulwaarde='AB-3D',
                                  label='AB-3D',
                                  status='ingebruik',
                                  definitie='AB-3D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3D'),
        'AB-4C': KeuzelijstWaarde(invulwaarde='AB-4C',
                                  label='AB-4C',
                                  status='ingebruik',
                                  definitie='AB-4C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-4C'),
        'AB-4D': KeuzelijstWaarde(invulwaarde='AB-4D',
                                  label='AB-4D',
                                  status='ingebruik',
                                  definitie='AB-4D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-4D'),
        'AB-5D': KeuzelijstWaarde(invulwaarde='AB-5D',
                                  label='AB-5D',
                                  status='ingebruik',
                                  definitie='AB-5D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-5D'),
        'ABT-B': KeuzelijstWaarde(invulwaarde='ABT-B',
                                  label='ABT-B',
                                  status='ingebruik',
                                  definitie='ABT-B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ABT-B'),
        'AGT-klasse-I': KeuzelijstWaarde(invulwaarde='AGT-klasse-I',
                                         label='AGT klasse I',
                                         status='ingebruik',
                                         definitie='AGT klasse I',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AGT-klasse-I'),
        'AGT-klasse-II': KeuzelijstWaarde(invulwaarde='AGT-klasse-II',
                                          label='AGT klasse II',
                                          status='ingebruik',
                                          definitie='AGT klasse II',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AGT-klasse-II'),
        'APO-A': KeuzelijstWaarde(invulwaarde='APO-A',
                                  label='APO-A',
                                  status='ingebruik',
                                  definitie='APO-A',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-A'),
        'APO-B': KeuzelijstWaarde(invulwaarde='APO-B',
                                  label='APO-B',
                                  status='ingebruik',
                                  definitie='APO-B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-B'),
        'APO-C': KeuzelijstWaarde(invulwaarde='APO-C',
                                  label='APO-C',
                                  status='ingebruik',
                                  definitie='APO-C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-C'),
        'APO-D': KeuzelijstWaarde(invulwaarde='APO-D',
                                  label='APO-D',
                                  status='ingebruik',
                                  definitie='APO-D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-D'),
        'APT-C': KeuzelijstWaarde(invulwaarde='APT-C',
                                  label='APT-C',
                                  status='ingebruik',
                                  definitie='APT-C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APT-C'),
        'APT-D': KeuzelijstWaarde(invulwaarde='APT-D',
                                  label='APT-D',
                                  status='ingebruik',
                                  definitie='APT-D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APT-D'),
        'AVS-B': KeuzelijstWaarde(invulwaarde='AVS-B',
                                  label='AVS-B',
                                  status='ingebruik',
                                  definitie='AVS-B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AVS-B'),
        'GA-C': KeuzelijstWaarde(invulwaarde='GA-C',
                                 label='GA-C',
                                 status='ingebruik',
                                 definitie='GA-C',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GA-C'),
        'GA-D': KeuzelijstWaarde(invulwaarde='GA-D',
                                 label='GA-D',
                                 status='ingebruik',
                                 definitie='GA-D',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GA-D'),
        'GA-E': KeuzelijstWaarde(invulwaarde='GA-E',
                                 label='GA-E',
                                 status='ingebruik',
                                 definitie='GA-E',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GA-E'),
        'GAA-E': KeuzelijstWaarde(invulwaarde='GAA-E',
                                  label='GAA-E',
                                  status='ingebruik',
                                  definitie='GAA-E',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GAA-E'),
        'GAB-D': KeuzelijstWaarde(invulwaarde='GAB-D',
                                  label='GAB-D',
                                  status='ingebruik',
                                  definitie='GAB-D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GAB-D'),
        'IA': KeuzelijstWaarde(invulwaarde='IA',
                               label='IA',
                               status='ingebruik',
                               definitie='IA',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IA'),
        'IB': KeuzelijstWaarde(invulwaarde='IB',
                               label='IB',
                               status='ingebruik',
                               definitie='IB',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IB'),
        'IC': KeuzelijstWaarde(invulwaarde='IC',
                               label='IC',
                               status='ingebruik',
                               definitie='IC',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IC'),
        'II': KeuzelijstWaarde(invulwaarde='II',
                               label='II',
                               status='ingebruik',
                               definitie='II',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/II'),
        'IIIA': KeuzelijstWaarde(invulwaarde='IIIA',
                                 label='IIIA',
                                 status='ingebruik',
                                 definitie='IIIA',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IIIA'),
        'IIIB': KeuzelijstWaarde(invulwaarde='IIIB',
                                 label='IIIB',
                                 status='ingebruik',
                                 definitie='IIIB',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IIIB'),
        'IIIC': KeuzelijstWaarde(invulwaarde='IIIC',
                                 label='IIIC',
                                 status='ingebruik',
                                 definitie='IIIC',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IIIC'),
        'IV': KeuzelijstWaarde(invulwaarde='IV',
                               label='IV',
                               status='ingebruik',
                               definitie='IV',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IV'),
        'SMA-B1': KeuzelijstWaarde(invulwaarde='SMA-B1',
                                   label='SMA-B1',
                                   status='ingebruik',
                                   definitie='SMA-B1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-B1'),
        'SMA-B2': KeuzelijstWaarde(invulwaarde='SMA-B2',
                                   label='SMA-B2',
                                   status='ingebruik',
                                   definitie='SMA-B2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-B2'),
        'SMA-C1': KeuzelijstWaarde(invulwaarde='SMA-C1',
                                   label='SMA-C1',
                                   status='ingebruik',
                                   definitie='SMA-C1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-C1'),
        'SMA-C2': KeuzelijstWaarde(invulwaarde='SMA-C2',
                                   label='SMA-C2',
                                   status='ingebruik',
                                   definitie='SMA-C2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-C2'),
        'SMA-D1': KeuzelijstWaarde(invulwaarde='SMA-D1',
                                   label='SMA-D1',
                                   status='ingebruik',
                                   definitie='SMA-D1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-D1'),
        'SMA-D2': KeuzelijstWaarde(invulwaarde='SMA-D2',
                                   label='SMA-D2',
                                   status='ingebruik',
                                   definitie='SMA-D2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-D2'),
        'ZOA-B1': KeuzelijstWaarde(invulwaarde='ZOA-B1',
                                   label='ZOA-B1',
                                   status='ingebruik',
                                   definitie='ZOA-B1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-B1'),
        'ZOA-B2': KeuzelijstWaarde(invulwaarde='ZOA-B2',
                                   label='ZOA-B2',
                                   status='ingebruik',
                                   definitie='ZOA-B2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-B2'),
        'ZOA-C1': KeuzelijstWaarde(invulwaarde='ZOA-C1',
                                   label='ZOA-C1',
                                   status='ingebruik',
                                   definitie='ZOA-C1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-C1'),
        'ZOA-C2': KeuzelijstWaarde(invulwaarde='ZOA-C2',
                                   label='ZOA-C2',
                                   status='ingebruik',
                                   definitie='ZOA-C2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-C2'),
        'gietasfalt': KeuzelijstWaarde(invulwaarde='gietasfalt',
                                       label='gietasfalt',
                                       status='ingebruik',
                                       definitie='gietasfalt',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/gietasfalt'),
        'onderlaag-APO-A-en-toplaag-AGT-klasse-I': KeuzelijstWaarde(invulwaarde='onderlaag-APO-A-en-toplaag-AGT-klasse-I',
                                                                    label='onderlaag APO-A en toplaag AGT klasse I',
                                                                    status='ingebruik',
                                                                    definitie='onderlaag APO-A en toplaag AGT klasse I',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-A-en-toplaag-AGT-klasse-I'),
        'onderlaag-APO-A-en-toplaag-AGT-klasse-II': KeuzelijstWaarde(invulwaarde='onderlaag-APO-A-en-toplaag-AGT-klasse-II',
                                                                     label='onderlaag APO-A en toplaag AGT klasse II',
                                                                     status='ingebruik',
                                                                     definitie='onderlaag APO-A en toplaag AGT klasse II',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-A-en-toplaag-AGT-klasse-II'),
        'onderlaag-APO-B-en-toplaag-AGT-klasse-I': KeuzelijstWaarde(invulwaarde='onderlaag-APO-B-en-toplaag-AGT-klasse-I',
                                                                    label='onderlaag APO-B en toplaag AGT klasse I',
                                                                    status='ingebruik',
                                                                    definitie='onderlaag APO-B en toplaag AGT klasse I',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-B-en-toplaag-AGT-klasse-I'),
        'onderlaag-APO-B-en-toplaag-AGT-klasse-II': KeuzelijstWaarde(invulwaarde='onderlaag-APO-B-en-toplaag-AGT-klasse-II',
                                                                     label='onderlaag APO-B en toplaag AGT klasse II',
                                                                     status='ingebruik',
                                                                     definitie='onderlaag APO-B en toplaag AGT klasse II',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-B-en-toplaag-AGT-klasse-II'),
        'toplaag-van-SMA-C': KeuzelijstWaarde(invulwaarde='toplaag-van-SMA-C',
                                              label='toplaag van SMA-C',
                                              status='ingebruik',
                                              definitie='toplaag van SMA-C',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-SMA-C'),
        'toplaag-van-SMA-D': KeuzelijstWaarde(invulwaarde='toplaag-van-SMA-D',
                                              label='toplaag van SMA-D',
                                              status='ingebruik',
                                              definitie='toplaag van SMA-D',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-SMA-D'),
        'toplaag-van-ZOA-B': KeuzelijstWaarde(invulwaarde='toplaag-van-ZOA-B',
                                              label='toplaag van ZOA-B',
                                              status='ingebruik',
                                              definitie='toplaag van ZOA-B',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-ZOA-B'),
        'toplaag-van-ZOA-C': KeuzelijstWaarde(invulwaarde='toplaag-van-ZOA-C',
                                              label='toplaag van ZOA-C',
                                              status='ingebruik',
                                              definitie='toplaag van ZOA-C',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-ZOA-C')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from datetime import date
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.Kast import Kast
from otlmow_model.OtlmowModel.BaseClasses.DateField import DateField
from ...Datatypes.KlAlgIngressProtectionCode import KlAlgIngressProtectionCode
from ...Datatypes.KlBuitenkastVerfraaid import KlBuitenkastVerfraaid
from ...Datatypes.KwantWrdInJaar import KwantWrdInJaar, KwantWrdInJaarWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Buitenkast(Kast):
    """Abstracte voor kasten die typisch buiten staan en daarom bestand moeten zijn tegen de elementen en verfraaiing kunnen krijgen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement', direction='u')  # u = unidirectional

        self._ipKlasse = OTLAttribuut(field=KlAlgIngressProtectionCode,
                                      naam='ipKlasse',
                                      label='ingress protection klasse',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast.ipKlasse',
                                      definition='De IP-codering als een aanduiding voor de mate van beveiliging van de constructie van elektrische of elektronische apparatuur tegen eigen schade door gebruik in "vijandige omgevingen" en tegen eventueel gevaar voor de gebruiker volgens IEC 60529.',
                                      owner=self)

        self._keuringsfrequentie = OTLAttribuut(field=KwantWrdInJaar,
                                                naam='keuringsfrequentie',
                                                label='keuringsfrequentie',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast.keuringsfrequentie',
                                                definition='Frequentie (in jaar) waarmee de kast moet onderworpen worden aan een periodieke keuring door een externe dienst voor technische controle.',
                                                owner=self)

        self._laatsteKeuringsdatum = OTLAttribuut(field=DateField,
                                                  naam='laatsteKeuringsdatum',
                                                  label='laatste keuringsdatum',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast.laatsteKeuringsdatum',
                                                  definition='Deze datum geeft aan wanneer de laatste keuring plaatsvond en kan gebruikt worden om te bepalen wanneer een volgende keuring nodig is.',
                                                  owner=self)

        self._verfraaid = OTLAttribuut(field=KlBuitenkastVerfraaid,
                                       naam='verfraaid',
                                       label='verfraaid',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast.verfraaid',
                                       definition='Geeft aan of de wegkantkast voorzien van verfraaiing en of die al dan niet vergund is.',
                                       owner=self)

    @property
    def ipKlasse(self) -> str:
        """De IP-codering als een aanduiding voor de mate van beveiliging van de constructie van elektrische of elektronische apparatuur tegen eigen schade door gebruik in "vijandige omgevingen" en tegen eventueel gevaar voor de gebruiker volgens IEC 60529."""
        return self._ipKlasse.get_waarde()

    @ipKlasse.setter
    def ipKlasse(self, value):
        self._ipKlasse.set_waarde(value, owner=self)

    @property
    def keuringsfrequentie(self) -> KwantWrdInJaarWaarden:
        """Frequentie (in jaar) waarmee de kast moet onderworpen worden aan een periodieke keuring door een externe dienst voor technische controle."""
        return self._keuringsfrequentie.get_waarde()

    @keuringsfrequentie.setter
    def keuringsfrequentie(self, value):
        self._keuringsfrequentie.set_waarde(value, owner=self)

    @property
    def laatsteKeuringsdatum(self) -> date:
        """Deze datum geeft aan wanneer de laatste keuring plaatsvond en kan gebruikt worden om te bepalen wanneer een volgende keuring nodig is."""
        return self._laatsteKeuringsdatum.get_waarde()

    @laatsteKeuringsdatum.setter
    def laatsteKeuringsdatum(self, value):
        self._laatsteKeuringsdatum.set_waarde(value, owner=self)

    @property
    def verfraaid(self) -> str:
        """Geeft aan of de wegkantkast voorzien van verfraaiing en of die al dan niet vergund is."""
        return self._verfraaid.get_waarde()

    @verfraaid.setter
    def verfraaid(self, value):
        self._verfraaid.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Proef import Proef
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefTextuurdiepte(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """Bepaling van de uitwasdiepte van de verharding na een oppervlaktebehandeling volgens NBN EN ISO 13473-1."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefTextuurdiepte'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BitumineuzeLaag', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding', direction='o')  # o = direction: outgoing

        self._textuurdiepte = OTLAttribuut(field=DtcDocument,
                                           naam='textuurdiepte',
                                           label='textuurdiepte',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefTextuurdiepte.textuurdiepte',
                                           definition='Proefresultaten van de textuurdiepte van de toplaag.',
                                           owner=self)

    @property
    def textuurdiepte(self) -> DtcDocumentWaarden:
        """Proefresultaten van de textuurdiepte van de toplaag."""
        return self._textuurdiepte.get_waarde()

    @textuurdiepte.setter
    def textuurdiepte(self, value):
        self._textuurdiepte.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAansluitingskabel(KeuzelijstField):
    """Keuzelijst voor de types van aansluitingskabel volgens de gebruikte verbinding."""
    naam = 'KlAansluitingskabel'
    label = 'Aansluitingskabel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAansluitingskabel'
    definition = 'Keuzelijst voor de types van aansluitingskabel volgens de gebruikte verbinding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAansluitingskabel'
    options = {
        'alarmkabel-2-10': KeuzelijstWaarde(invulwaarde='alarmkabel-2-10',
                                            label='alarmkabel 2+10',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/alarmkabel-2-10'),
        'alarmkabel-2-4': KeuzelijstWaarde(invulwaarde='alarmkabel-2-4',
                                           label='alarmkabel 2+4',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/alarmkabel-2-4'),
        'alarmkabel-2-6': KeuzelijstWaarde(invulwaarde='alarmkabel-2-6',
                                           label='alarmkabel 2+6',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/alarmkabel-2-6'),
        'alarmkabel-2-8': KeuzelijstWaarde(invulwaarde='alarmkabel-2-8',
                                           label='alarmkabel 2+8',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/alarmkabel-2-8'),
        'draadloos': KeuzelijstWaarde(invulwaarde='draadloos',
                                      label='draadloos',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/draadloos'),
        'lihch': KeuzelijstWaarde(invulwaarde='lihch',
                                  label='LIHCH',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/lihch'),
        'lihh': KeuzelijstWaarde(invulwaarde='lihh',
                                 label='LIHH',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/lihh'),
        'liycy': KeuzelijstWaarde(invulwaarde='liycy',
                                  label='LIYCY',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/liycy'),
        'liyy': KeuzelijstWaarde(invulwaarde='liyy',
                                 label='LIYY',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/liyy'),
        'telefoonkabel': KeuzelijstWaarde(invulwaarde='telefoonkabel',
                                          label='telefoonkabel',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/telefoonkabel'),
        'utp': KeuzelijstWaarde(invulwaarde='utp',
                                label='UTP',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/utp'),
        'xgb': KeuzelijstWaarde(invulwaarde='xgb',
                                label='XGB',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/xgb'),
        'xvb': KeuzelijstWaarde(invulwaarde='xvb',
                                label='XVB',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingskabel/xvb')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Spindelmoer(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een moer die op een spindel is bevestigd en die beweegt wanneer de spindel draait en zo een lineaire beweging creëert die kan worden gebruikt voor het aansturen van mechanische bewegingen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spindelmoer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spindel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Spindelmechanisme', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlToegangscontroleSleuteltype import KlToegangscontroleSleuteltype
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Toegangscontrole(NaampadObject, PuntGeometrie):
    """Component voor controle van de toegang tot een ruimte of behuizing."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontrole'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.16.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing', direction='u', deprecated='2.16.0')  # u = unidirectional

        self._heeftBadgelezer = OTLAttribuut(field=BooleanField,
                                             naam='heeftBadgelezer',
                                             label='heeft badgelezer',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontrole.heeftBadgelezer',
                                             usagenote='Klasse uit gebruik sinds versie 2.16.0 ',
                                             deprecated_version='2.16.0',
                                             definition='Geeft aan of de toegangscontrole uitgerust is met een badgelezer.',
                                             owner=self)

        self._heeftSlotMetAfstandsbediening = OTLAttribuut(field=BooleanField,
                                                           naam='heeftSlotMetAfstandsbediening',
                                                           label='heeft slot met afstandsbediening',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontrole.heeftSlotMetAfstandsbediening',
                                                           usagenote='Klasse uit gebruik sinds versie 2.16.0 ',
                                                           deprecated_version='2.16.0',
                                                           definition='Geeft aan of het objecttype waaraan de toegangscontrole bevestigd is, kan geopend worden via een slot met afstandsbediening.',
                                                           owner=self)

        self._sleutelType = OTLAttribuut(field=KlToegangscontroleSleuteltype,
                                         naam='sleutelType',
                                         label='type sleutel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontrole.sleutelType',
                                         usagenote='Klasse uit gebruik sinds versie 2.16.0 ',
                                         deprecated_version='2.16.0',
                                         definition='De soort sleutel die wordt gebruikt om de toegang te regelen.',
                                         owner=self)

    @property
    def heeftBadgelezer(self) -> bool:
        """Geeft aan of de toegangscontrole uitgerust is met een badgelezer."""
        return self._heeftBadgelezer.get_waarde()

    @heeftBadgelezer.setter
    def heeftBadgelezer(self, value):
        self._heeftBadgelezer.set_waarde(value, owner=self)

    @property
    def heeftSlotMetAfstandsbediening(self) -> bool:
        """Geeft aan of het objecttype waaraan de toegangscontrole bevestigd is, kan geopend worden via een slot met afstandsbediening."""
        return self._heeftSlotMetAfstandsbediening.get_waarde()

    @heeftSlotMetAfstandsbediening.setter
    def heeftSlotMetAfstandsbediening(self, value):
        self._heeftSlotMetAfstandsbediening.set_waarde(value, owner=self)

    @property
    def sleutelType(self) -> str:
        """De soort sleutel die wordt gebruikt om de toegang te regelen."""
        return self._sleutelType.get_waarde()

    @sleutelType.setter
    def sleutelType(self, value):
        self._sleutelType.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlIOKaartModelnaam(KeuzelijstField):
    """Lijst van mogelijke modelnamen voor IO-kaarten."""
    naam = 'KlIOKaartModelnaam'
    label = 'IO-kaart modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlIOKaartModelnaam'
    definition = 'Lijst van mogelijke modelnamen voor IO-kaarten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlIOKaartModelnaam'
    options = {
        'axl-f-ai4-i-1h': KeuzelijstWaarde(invulwaarde='axl-f-ai4-i-1h',
                                           label='AXL F AI4 I 1H',
                                           status='ingebruik',
                                           definitie='AXL F AI4 I 1H',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartModelnaam/axl-f-ai4-i-1h'),
        'dri701': KeuzelijstWaarde(invulwaarde='dri701',
                                   label='DRI701',
                                   status='ingebruik',
                                   definitie='DRI701',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartModelnaam/dri701'),
        'pma701': KeuzelijstWaarde(invulwaarde='pma701',
                                   label='PMA701',
                                   status='ingebruik',
                                   definitie='PMA701',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartModelnaam/pma701'),
        'pms701': KeuzelijstWaarde(invulwaarde='pms701',
                                   label='PMS701',
                                   status='ingebruik',
                                   definitie='PMS701',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartModelnaam/pms701'),
        'siu701': KeuzelijstWaarde(invulwaarde='siu701',
                                   label='SIU701',
                                   status='ingebruik',
                                   definitie='SIU701',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOKaartModelnaam/siu701')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.RHZModule import RHZModule
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from ...Datatypes.KlOmvormerMerk import KlOmvormerMerk
from ...Datatypes.KlOmvormerModelnaam import KlOmvormerModelnaam
from ...Datatypes.KlOmvormerType import KlOmvormerType
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Omvormer(RHZModule, NaampadObject, PuntGeometrie):
    """Een object, bijna altijd geplaatst in paar geplaatst, omvorming en "de"-omvorming, dat een signaal binnenneemt en terug uitstuurt maar dan op een andere manier. Er zijn een hele reeks manieren. - Omvorming waar er gewijzigd wordt van type kabel om dezelfde boodschap over te versturen, bv. omvorming van UTP naar Coax. - Omvorming van codering bv. analoog naar digitaal en in omgekeerde richting digitaal naar analoog (omvorming van codering analoog-digitaal verschilt van een encoder omdat een encoder een eindproduct aflevert; in dit geval is de omvorming ter ondersteuning het transport en zal er altijd een omvorming zijn terug naar analoog) - Omvorming die de gegevens opnieuw versterkt zodat ze over een langere afstand kunnen getransporteerd worden. Deze variant heeft niet noodzakelijk een tweede omvormer om terug te gaan naar het origineel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LEDBord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Silo', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermbuis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Datakabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Signaalkabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedingskabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LEDBord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Sensor', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AIDModule', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NetwerkModem', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spanningsomvormer', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i')  # i = direction: incoming

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='ip adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer.ipAdres',
                                     definition='Het IP-adres van de omvormer.',
                                     owner=self)

        self._merk = OTLAttribuut(field=KlOmvormerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer.merk',
                                  definition='Het merk van de omvormer.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlOmvormerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer.modelnaam',
                                       definition='De modelnaam van de omvormer.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer.technischeFiche',
                                             usagenote='Bestanden van het type pdf.',
                                             definition='Technische fiche van de omvormer.',
                                             owner=self)

        self._type = OTLAttribuut(field=KlOmvormerType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer.type',
                                  definition='De soort omvorming die gebeurt er in de omvormer.',
                                  owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """Het IP-adres van de omvormer."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de omvormer."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de omvormer."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technische fiche van de omvormer."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """De soort omvorming die gebeurt er in de omvormer."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



from abc import abstractmethod
from typing import Any


class OTLField:
    waarde_shortcut_applicable: bool = False
    naam: str = ''
    label: str = ''
    objectUri: str = ''
    definition: str = ''
    usagenote: str = ''
    deprecated_version: str = ''
    waardeObject: Any = None
    clearing_value: Any = None
    native_type: Any

    @classmethod
    def validate(cls, value: Any, attribuut) -> bool:
        if not attribuut.field.waardeObject:
            return
        if isinstance(value, list):
            for list_item in value:
                if not isinstance(list_item, attribuut.field.waardeObject):
                    raise ValueError(
                        f'{attribuut.objectUri} is a complex datatype. Set the values through the attributes. '
                        f'Use .attr_type_info() for more info')
        elif not isinstance(value, attribuut.field.waardeObject):
            raise ValueError(
                f'{attribuut.objectUri} is a complex datatype. Set the values through the attributes. '
                f'Use .attr_type_info() for more info')
        validation = True
        for attr in value:
            if attr.waarde is None:
                continue
            if attr.kardinaliteit_max != '1':
                for value_item in attr.waarde:
                    if not attr.field.validate(value_item, attr):
                        validation = False
                        break
            elif not attr.field.validate(attr.waarde, attr):
                validation = False
                break
        return validation

    @classmethod
    def value_default(cls, value: Any) -> Any:
        return value

    @classmethod
    def convert_to_correct_type(cls, value: Any, log_warnings: bool = True) -> Any:
        return value

    @abstractmethod
    def __str__(self) -> str:
        return f"""information about {self.naam}:
naam: {self.naam}
uri: {self.objectUri}
definition: {self.definition}
label: {self.label}
usagenote: {self.usagenote}
deprecated_version: {self.deprecated_version}"""

    @classmethod
    def create_dummy_data(cls):
        raise NotImplementedError()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAfwerkingstypeLeuning(KeuzelijstField):
    """Geeft de afwerking van de leuning weer."""
    naam = 'KlAfwerkingstypeLeuning'
    label = 'Afwerkingstype leuning'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlAfwerkingstypeLeuning'
    definition = 'Geeft de afwerking van de leuning weer.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAfwerkingstypeLeuning'
    options = {
        'gegalvaniseerd': KeuzelijstWaarde(invulwaarde='gegalvaniseerd',
                                           label='Gegalvaniseerd',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfwerkingstypeLeuning/gegalvaniseerd'),
        'geverfd': KeuzelijstWaarde(invulwaarde='geverfd',
                                    label='Geverfd',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfwerkingstypeLeuning/geverfd'),
        'roestvrij-cortenstaal': KeuzelijstWaarde(invulwaarde='roestvrij-cortenstaal',
                                                  label='Roestvrij cortenstaal',
                                                  status='ingebruik',
                                                  definitie='roestvrij cortenstaal',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfwerkingstypeLeuning/roestvrij-cortenstaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPositieKolk(KeuzelijstField):
    """De mogelije posities van een kolk."""
    naam = 'KlPositieKolk'
    label = 'Positie kolk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlPositieKolk'
    definition = 'De mogelije posities van een kolk.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPositieKolk'
    options = {
        'afwaarts': KeuzelijstWaarde(invulwaarde='afwaarts',
                                     label='afwaarts',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPositieKolk/afwaarts'),
        'opwaarts': KeuzelijstWaarde(invulwaarde='opwaarts',
                                     label='opwaarts',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPositieKolk/opwaarts'),
        'slechts-1-kolkdeel': KeuzelijstWaarde(invulwaarde='slechts-1-kolkdeel',
                                               label='slechts 1 kolkdeel',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPositieKolk/slechts-1-kolkdeel')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.LaagBouwklasse import LaagBouwklasse
from ...Datatypes.DtcSupplementenCBV import DtcSupplementenCBV, DtcSupplementenCBVWaarden
from otlmow_model.OtlmowModel.BaseClasses.IntegerField import IntegerField
from ...Datatypes.KlCBVAardVerharding import KlCBVAardVerharding
from ...Datatypes.KlCBVLaagtype import KlCBVLaagtype
from ...Datatypes.KlCBVOppervlaktebehandeling import KlCBVOppervlaktebehandeling
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Cementbetonverharding(LaagBouwklasse):
    """Stijve verharding met of zonder wapening verkregen door cementbeton te spreiden en mechanisch te verdichten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SelNietSelLus', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Straatmeubilair', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Divergentiepuntbebakeningselement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringslandhoofd', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegdekvoeg', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegreflector', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefConsistentie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefDruksterkte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefGemetenDikte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefHechtsterkte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefLangsvlakheid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefLuchtgehalte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefRolgeluid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefStaalvezelgehalte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefStroefheid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefTextuurdiepte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefVerankeringskracht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefVlakheid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefWatergehalte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefWateropslorping', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefWeerstandAfschilfering', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BegroeidVoorkomen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LijnvormigElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VegetatieElement', direction='i')  # i = direction: incoming

        self._aantalAnkerstaven = OTLAttribuut(field=IntegerField,
                                               naam='aantalAnkerstaven',
                                               label='aantal ankerstaven',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.aantalAnkerstaven',
                                               definition='Aantal ankerstaven waarmee de voegen verankerd zijn.',
                                               owner=self)

        self._aardVerharding = OTLAttribuut(field=KlCBVAardVerharding,
                                            naam='aardVerharding',
                                            label='aard verharding',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.aardVerharding',
                                            definition='De uitvoeringswijze van de cementbetonverharding.',
                                            owner=self)

        self._krimpvoegFrequentie = OTLAttribuut(field=KwantWrdInMeter,
                                                 naam='krimpvoegFrequentie',
                                                 label='krimpvoeg frequentie',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.krimpvoegFrequentie',
                                                 definition='De afstand tussen de krimpvoegen in meter.',
                                                 owner=self)

        self._laagtype = OTLAttribuut(field=KlCBVLaagtype,
                                      naam='laagtype',
                                      label='laagtype',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.laagtype',
                                      definition='Het type van de cementbetonverhardingslaag.',
                                      owner=self)

        self._oppervlakbehandeling = OTLAttribuut(field=KlCBVOppervlaktebehandeling,
                                                  naam='oppervlakbehandeling',
                                                  label='oppervlakbehandeling',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.oppervlakbehandeling',
                                                  definition='Behandeling die wordt toegepast op het oppervlak van een laag, met of zonder toevoeging van materialen, en bestemd is om de eigenschappen van de laag te verbeteren, hetzij bij de uitvoering, hetzij achteraf.',
                                                  owner=self)

        self._supplementen = OTLAttribuut(field=DtcSupplementenCBV,
                                          naam='supplementen',
                                          label='supplementen van de verharding',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.supplementen',
                                          definition='Additionele toevoegingen aan de verharding.',
                                          owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding.volume',
                                    definition='Het volume van cementbetonverharding in kubieke meter.',
                                    owner=self)

    @property
    def aantalAnkerstaven(self) -> int:
        """Aantal ankerstaven waarmee de voegen verankerd zijn."""
        return self._aantalAnkerstaven.get_waarde()

    @aantalAnkerstaven.setter
    def aantalAnkerstaven(self, value):
        self._aantalAnkerstaven.set_waarde(value, owner=self)

    @property
    def aardVerharding(self) -> str:
        """De uitvoeringswijze van de cementbetonverharding."""
        return self._aardVerharding.get_waarde()

    @aardVerharding.setter
    def aardVerharding(self, value):
        self._aardVerharding.set_waarde(value, owner=self)

    @property
    def krimpvoegFrequentie(self) -> KwantWrdInMeterWaarden:
        """De afstand tussen de krimpvoegen in meter."""
        return self._krimpvoegFrequentie.get_waarde()

    @krimpvoegFrequentie.setter
    def krimpvoegFrequentie(self, value):
        self._krimpvoegFrequentie.set_waarde(value, owner=self)

    @property
    def laagtype(self) -> str:
        """Het type van de cementbetonverhardingslaag."""
        return self._laagtype.get_waarde()

    @laagtype.setter
    def laagtype(self, value):
        self._laagtype.set_waarde(value, owner=self)

    @property
    def oppervlakbehandeling(self) -> str:
        """Behandeling die wordt toegepast op het oppervlak van een laag, met of zonder toevoeging van materialen, en bestemd is om de eigenschappen van de laag te verbeteren, hetzij bij de uitvoering, hetzij achteraf."""
        return self._oppervlakbehandeling.get_waarde()

    @oppervlakbehandeling.setter
    def oppervlakbehandeling(self, value):
        self._oppervlakbehandeling.set_waarde(value, owner=self)

    @property
    def supplementen(self) -> DtcSupplementenCBVWaarden:
        """Additionele toevoegingen aan de verharding."""
        return self._supplementen.get_waarde()

    @supplementen.setter
    def supplementen(self, value):
        self._supplementen.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het volume van cementbetonverharding in kubieke meter."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeGrondanker(KeuzelijstField):
    """De mogelijke types grondanker."""
    naam = 'KlTypeGrondanker'
    label = 'Type grondanker'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlTypeGrondanker'
    definition = 'De mogelijke types grondanker.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeGrondanker'
    options = {
        'duo': KeuzelijstWaarde(invulwaarde='duo',
                                label='duo',
                                status='ingebruik',
                                definitie='duo',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeGrondanker/duo'),
        'gestaffeld': KeuzelijstWaarde(invulwaarde='gestaffeld',
                                       label='gestaffeld',
                                       status='ingebruik',
                                       definitie='gestaffeld',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeGrondanker/gestaffeld'),
        'mono': KeuzelijstWaarde(invulwaarde='mono',
                                 label='mono',
                                 status='ingebruik',
                                 definitie='mono',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeGrondanker/mono')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeBolder(KeuzelijstField):
    """De mogelijke typen van een bolder."""
    naam = 'KlTypeBolder'
    label = 'Type bolder'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTypeBolder'
    definition = 'De mogelijke typen van een bolder.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeBolder'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='andere',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/andere'),
        'dubbele-kikker': KeuzelijstWaarde(invulwaarde='dubbele-kikker',
                                           label='dubbele kikker',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/dubbele-kikker'),
        'dubbele-kruis': KeuzelijstWaarde(invulwaarde='dubbele-kruis',
                                          label='dubbele kruis',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/dubbele-kruis'),
        'dubbele-paddenstoel': KeuzelijstWaarde(invulwaarde='dubbele-paddenstoel',
                                                label='dubbele paddenstoel',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/dubbele-paddenstoel'),
        'dubbele-t-hoofd': KeuzelijstWaarde(invulwaarde='dubbele-t-hoofd',
                                            label='dubbele T-hoofd',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/dubbele-t-hoofd'),
        'hoorns': KeuzelijstWaarde(invulwaarde='hoorns',
                                   label='hoorns',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/hoorns'),
        'kikker': KeuzelijstWaarde(invulwaarde='kikker',
                                   label='kikker',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/kikker'),
        'kruis': KeuzelijstWaarde(invulwaarde='kruis',
                                  label='kruis',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/kruis'),
        'paddenstoel': KeuzelijstWaarde(invulwaarde='paddenstoel',
                                        label='paddenstoel',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/paddenstoel'),
        'quick-release': KeuzelijstWaarde(invulwaarde='quick-release',
                                          label='quick release',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/quick-release'),
        't-hoofd': KeuzelijstWaarde(invulwaarde='t-hoofd',
                                    label='t-hoofd',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBolder/t-hoofd')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBypassSchakelaarLocatie(KeuzelijstField):
    """De mogelijke locaties van een bypass schakelaar."""
    naam = 'KlBypassSchakelaarLocatie'
    label = 'Bypass schakelaar locatie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBypassSchakelaarLocatie'
    definition = 'De mogelijke locaties van een bypass schakelaar.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBypassSchakelaarLocatie'
    options = {
        'laagspanningsbord': KeuzelijstWaarde(invulwaarde='laagspanningsbord',
                                              label='Laagspanningsbord',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBypassSchakelaarLocatie/laagspanningsbord'),
        'ups': KeuzelijstWaarde(invulwaarde='ups',
                                label='UPS',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBypassSchakelaarLocatie/ups')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Geluidsschermelement import Geluidsschermelement
from ...Datatypes.KlVGOpstelling import KlVGOpstelling
from ...Datatypes.KlVGSchermelementtype import KlVGSchermelementtype
from ...Datatypes.KlVormSchermelement import KlVormSchermelement


# Generated with OTLClassCreator. To modify: extend, do not edit
class VlakGeluidsschermelement(Geluidsschermelement):
    """Een vlak scherm zijn alle schermtypes die getest kunnen worden volgens de normen NBN EN 1793-1 NBN EN 1793-2."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VlakGeluidsschermelement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BevestigingGC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementenGC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VegetatieElement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VlakGeluidsschermelement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Geluidsschermelement', direction='i')  # i = direction: incoming

        self._opstelling = OTLAttribuut(field=KlVGOpstelling,
                                        naam='opstelling',
                                        label='opstelling',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VlakGeluidsschermelement.opstelling',
                                        definition='Dit attribuut beschrijft de oriëntatie van het geplaatste schermelement t.o.v. de weg. De oriëntatie van vlakke schermen kan naast loodrecht op het maaiveld ook schuin naar achter hellend of schuin naar voor hellend zijn.',
                                        owner=self)

        self._schermelementtype = OTLAttribuut(field=KlVGSchermelementtype,
                                               naam='schermelementtype',
                                               label='schermelementtype',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VlakGeluidsschermelement.schermelementtype',
                                               definition='Het type vlak-schermelement.',
                                               owner=self)

        self._vorm = OTLAttribuut(field=KlVormSchermelement,
                                  naam='vorm',
                                  label='vorm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VlakGeluidsschermelement.vorm',
                                  definition='Dit attribuut geeft aan of het schermelement recht of gebogen is.',
                                  owner=self)

    @property
    def opstelling(self) -> str:
        """Dit attribuut beschrijft de oriëntatie van het geplaatste schermelement t.o.v. de weg. De oriëntatie van vlakke schermen kan naast loodrecht op het maaiveld ook schuin naar achter hellend of schuin naar voor hellend zijn."""
        return self._opstelling.get_waarde()

    @opstelling.setter
    def opstelling(self, value):
        self._opstelling.set_waarde(value, owner=self)

    @property
    def schermelementtype(self) -> str:
        """Het type vlak-schermelement."""
        return self._schermelementtype.get_waarde()

    @schermelementtype.setter
    def schermelementtype(self, value):
        self._schermelementtype.set_waarde(value, owner=self)

    @property
    def vorm(self) -> str:
        """Dit attribuut geeft aan of het schermelement recht of gebogen is."""
        return self._vorm.get_waarde()

    @vorm.setter
    def vorm(self, value):
        self._vorm.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.KlVervuilingSoorten import KlVervuilingSoorten
from ..Datatypes.KwantWrdInMicrogramPerKilogram import KwantWrdInMicrogramPerKilogram, KwantWrdInMicrogramPerKilogramWaarden


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcSoortVervuilingWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._microgramPerKilogram = OTLAttribuut(field=KwantWrdInMicrogramPerKilogram,
                                                  naam='microgramPerKilogram',
                                                  label='microgram per kilogram',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcSoortVervuiling.microgramPerKilogram',
                                                  kardinaliteit_max='3',
                                                  definition='De concentratie van de vervuiling kan in µg/kg bepaalt worden.',
                                                  owner=self)

        self._soortVervuiling = OTLAttribuut(field=KlVervuilingSoorten,
                                             naam='soortVervuiling',
                                             label='soort vervuiling',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcSoortVervuiling.soortVervuiling',
                                             definition='Het soort vervuiling kan hiermee bepaalt worden.',
                                             owner=self)

    @property
    def microgramPerKilogram(self) -> List[KwantWrdInMicrogramPerKilogramWaarden]:
        """De concentratie van de vervuiling kan in µg/kg bepaalt worden."""
        return self._microgramPerKilogram.get_waarde()

    @microgramPerKilogram.setter
    def microgramPerKilogram(self, value):
        self._microgramPerKilogram.set_waarde(value, owner=self._parent)

    @property
    def soortVervuiling(self) -> str:
        """Het soort vervuiling kan hiermee bepaalt worden."""
        return self._soortVervuiling.get_waarde()

    @soortVervuiling.setter
    def soortVervuiling(self, value):
        self._soortVervuiling.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcSoortVervuiling(ComplexField):
    """Complex datatype om het soort vervuiling te bepalen."""
    naam = 'DtcSoortVervuiling'
    label = 'soort vervuiling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcSoortVervuiling'
    definition = 'Complex datatype om het soort vervuiling te bepalen.'
    waardeObject = DtcSoortVervuilingWaarden

    def __str__(self):
        return ComplexField.__str__(self)

